@@ -8,4 +8,4 @@ class Bootstrap(ComponentResource):
         super().__init__('Bootstrap', name, {}, opts)
 
         # Create bootstrap resource group
-        bootstrap_rg = resource_group.resource_group('bootstrap', props, ResourceOptions.provider)
+        bootstrap_rg = resource_group.resource_group('bootstrap', props)
